import { AbstractResponse } from '../AbstractResponse';
import { Paging, PagingData } from '../data/Paging';
/**
 * Class that represents a response from a request that simply returns an array of id objects.
 *
 * @author Tiago Grosso <tiagogrosso99@gmail.com>
 * @since 1.2.0
 */
export declare class ManyIdsResponse extends AbstractResponse<{
    id: string;
}[]> {
    /**
     * The paging of the response.
     */
    private readonly paging;
    /**
     * The constructor.
     *
     * @param body the body of the response
     */
    constructor(body: {
        data: {
            id: string;
        }[];
        paging: PagingData;
    });
    /**
     * Gets the ids in the response.
     *
     * @returns the ids in the response.
     */
    getIds(): string[];
    /**
     * Gets the paging of the response.
     *
     * @returns the paging of the response.
     */
    getPaging(): Paging;
}
