/**
 * Interface to represent the paging data in a paged response.
 *
 * @author Tiago Grosso <tiagogrosso99@gmail.com>
 * @since 0.1.0
 */
export interface PagingData {
    /**
     * The previous page of the response.
     */
    previous?: string;
    /**
     * The next page of the response.
     */
    next?: string;
    /**
     * The {@link Cursors} of the response.
     */
    cursors?: Cursors;
}
/**
 * Interface to represent the cursors of a paged response.
 *
 * @author Tiago Grosso <tiagogrosso99@gmail.com>
 * @since 0.1.0
 */
export interface Cursors {
    /**
     * The object before the one of the response.
     */
    before?: string;
    /**
     * The object after the one of the response.
     */
    after?: string;
}
/**
 * Class to represent the Paging of a paged response.
 *
 * @author Tiago Grosso <tiagogrosso99@gmail.com>
 * @since 0.1.0
 */
export declare class Paging {
    /**
     * The paging data.
     */
    private readonly pagingData;
    /**
     * The constructor.
     *
     * @param pagingData the paging data.
     */
    constructor(pagingData: PagingData);
    /**
     * Gets the paging of the response.
     *
     * @returns the paging of the response.
     */
    getPaging(): PagingData;
    /**
     * Gets the cursors of the response.
     *
     * @returns the cursors of the response.
     */
    getCursors(): Cursors | undefined;
    /**
     * Gets the previous page of the response.
     *
     * @returns the previous page of the response.
     */
    getPrevious(): string | undefined;
    /**
     * Gets the next page of the response.
     *
     * @returns the next page of the response.
     */
    getNext(): string | undefined;
    /**
     * Gets the object before the one in the response.
     *
     * @returns the object before the one in the response.
     */
    getBefore(): string | undefined;
    /**
     * Gets the object after the one in the response.
     *
     * @returns the object after the one in the response.
     */
    getAfter(): string | undefined;
}
