import { MediaProductType } from '../../../Enums';
import { AbstractResponse } from '../../AbstractResponse';
import { MediaData } from '../../data/MediaData';
/**
 * Class that represents a response from a Media request.
 *
 * @author Tiago Grosso <tiagogrosso99@gmail.com>
 * @since 0.1.0
 */
export declare class GetMediaInfoResponse extends AbstractResponse<MediaData> {
    /**
     * Gets the id of the media object.
     *
     * @returns the id of the media object.
     */
    getId(): string;
    /**
     * Gets the caption of the media object.
     *
     * @returns the caption of the media object.
     */
    getCaption(): string | undefined;
    /**
     * Gets the ig_id of the media object.
     *
     * @returns the ig_id of the media object.
     */
    getIgId(): string | undefined;
    /**
     * Gets the comments count of the media object.
     *
     * @returns the comments count of the media object.
     */
    getCommentsCount(): number | undefined;
    /**
     * Whether comments are enabled on the media object.
     *
     * @returns whether comments are enabled on the media object.
     */
    isCommentsEnabled(): boolean | undefined;
    /**
     * Gets the like count of the media object.
     *
     * @returns the like count of the media object.
     */
    getLikeCount(): number | undefined;
    /**
     * Gets the type of the media object.
     *
     * @returns the type of the media object.
     */
    getMediaType(): string | undefined;
    /**
     * Gets the URL of the media object.
     *
     * @returns the URL of the media object.
     */
    getMediaUrl(): string | undefined;
    /**
     * Gets the owner of the media object.
     *
     * @returns the owner of the media object.
     */
    getOwner(): {
        id: string;
    } | undefined;
    /**
     * Gets the owner id of the media object.
     *
     * @returns the owner id of the media object.
     */
    getOwnerId(): string | undefined;
    /**
     * Gets the permalink of the media object.
     *
     * @returns the permalink of the media object.
     */
    getPermalink(): string | undefined;
    /**
     * Gets the shortcode of the media object.
     *
     * @returns the shortcode of the media object.
     */
    getShortcode(): string | undefined;
    /**
     * Gets the timestamp of the media object.
     *
     * @returns the timestamp of the media object.
     */
    getTimestamp(): Date | undefined;
    /**
     * Gets the username of the media object.
     *
     * @returns the username of the media object.
     */
    getUsername(): string | undefined;
    /**
     * Gets the surface where the media is published.
     *
     * @returns the surface where the media is published.
     */
    getMediaProductType(): MediaProductType | undefined;
    /**
     * Gets the video title of the IGTV media object.
     *
     * @returns the video title of the IGTV media object.
     */
    getVideoTitle(): string | undefined;
}
