import { AbstractResponse } from '../../AbstractResponse';
import { PageInfoData } from '../../data/PageInfoData';
/**
 * Class that represents a response from a Page Info request.
 *
 * @author Tiago Grosso <tiagogrosso99@gmail.com>
 * @since 0.1.0
 */
export declare class GetPageInfoResponse extends AbstractResponse<PageInfoData> {
    /**
     * Gets the id of the page.
     *
     * @returns the id of the page.
     */
    getId(): string;
    /**
     * Gets the biography of the page.
     *
     * @returns the biography of the page.
     */
    getBiography(): string | undefined;
    /**
     * Gets the Instagram id of the page.
     *
     * @returns the Instagram id of the page.
     */
    getIgId(): string | undefined;
    /**
     * Gets the number of page followers.
     *
     * @returns the number of page followers.
     */
    getFollowers(): number | undefined;
    /**
     * Gets the number of page follows.
     *
     * @returns the number of page follows.
     */
    getFollows(): number | undefined;
    /**
     * Gets the number of media objects in the page.
     *
     * @returns the number of media objects in the page.
     */
    getMediaCount(): number | undefined;
    /**
     * Gets the name of the page.
     *
     * @returns the name of the page.
     */
    getName(): string | undefined;
    /**
     * Gets the URL of the profile picture of the page.
     *
     * @returns the URL of the profile picture of the page.
     */
    getProfilePictureUrl(): string | undefined;
    /**
     * Gets the username of the page.
     *
     * @returns the username of the page.
     */
    getUsername(): string | undefined;
}
