import { MediaType } from './AbstractPostPageMediaRequest';
import { AbstractPostPageTimelineMediaRequest } from './AbstractPostTimelineMediaRequest';
/**
 * A request that creates a new Carousel Media container.
 *
 * @author Tiago Grosso <tiagogrosso99@gmail.com>
 * @since 3.0.0
 */
export declare class PostPageCarouselMediaRequest extends AbstractPostPageTimelineMediaRequest {
    /**
     * The constructor
     *
     * @param accessToken the access token.
     * @param pageId the page id.
     * @param children the video URL.
     * @param caption the caption.
     * @param locationId the location id.
     */
    constructor(accessToken: string, pageId: string, children?: string[], caption?: string, locationId?: string);
    /**
     * Sets the children param in the request.
     *
     * @param children the children.
     *
     * @returns this object, for chained invocation.
     */
    withChildren(children: string[]): this;
    /**
     * Adds children to the children param in the request.
     *
     * @param children the children to add.
     *
     * @returns this object, for chained invocation.
     */
    addChildren(...children: string[]): this;
    /**
     * Removes children from the children param in the request.
     *
     * @param children the children to remove.
     *
     * @returns this object, for chained invocation.
     */
    removeChildren(...children: string[]): this;
    /**
     * @inheritdoc
     */
    protected mediaType(): MediaType;
}
