import { MediaType } from './AbstractPostPageMediaRequest';
import { AbstractPostPageTimelineMediaRequest } from './AbstractPostTimelineMediaRequest';
/**
 * * A request that creates a new Reels Media container.
 *  *
 *  * @author Tiago Grosso <tiagogrosso99@gmail.com>
 *  * @since 5.0.0
 *  */
export declare class PostPageReelMediaRequest extends AbstractPostPageTimelineMediaRequest {
    /**
     * The constructor
     *
     * @param accessToken the access token.
     * @param pageId the page id.
     * @param videoUrl the video URL.
     * @param caption the caption.
     * @param thumbOffset the thumbnail offset.
     * @param shareToFeed whether the reel should be shared in the feed as well.
     * @param locationId the location id.
     */
    constructor(accessToken: string, pageId: string, videoUrl: string, caption?: string, thumbOffset?: number, shareToFeed?: boolean, locationId?: string);
    /**
     * Sets the thumbnail offset time in the request.
     *
     * @param thumbOffset the thumbnail offset time.
     *
     * @returns this object, for chained invocation.
     */
    withThumbOffset(thumbOffset: number): this;
    /**
     * Sets whether the reel should be shared in the feed as well.
     *
     * @param shareToFeed whether the reel should be shared in the feed as well.
     *
     * @returns this object, for chained invocation.
     */
    withShareToFeed(shareToFeed: boolean): this;
    /**
     * @inheritdoc
     */
    protected mediaType(): MediaType | undefined;
}
