import { AbstractRequest } from '../../AbstractRequest';
import { GetUserLongLivedTokenResponse } from './GetUserLongLivedTokenResponse';
import { UserLongLivedTokenData } from '../../data/UserLongLivedTokenData';
/**
 * This class is used to exchange a short-lived-token by a long-lived-token that you get when
 * the user performs a Facebook login in your page and wants to authorize your app
 * to make requests for longer than a short-lived token's expiration.
 *
 * This long-lived-token last ~60 days according to Facebook documentation:
 * https://developers.facebook.com/docs/facebook-login/access-tokens/refreshing
 *
 * @author Andres Gutierrez <andres99@gmail.com>
 * @since 2.0.0
 */
export declare class GetUserLongLivedTokenRequest extends AbstractRequest<GetUserLongLivedTokenResponse> {
    /**
     * The app id.
     */
    appId: string;
    /**
     * The app secret id.
     */
    appSecretId: string;
    /**
     * The constructor.
     *
     * @param accessToken the access token.
     * @param appId the app id.
     * @param appSecretId the app secret id.
     */
    constructor(accessToken: string, appId: string, appSecretId: string);
    /**
     * @inheritdoc
     */
    protected parseResponse(response: UserLongLivedTokenData): GetUserLongLivedTokenResponse;
    /**
     * @inheritdoc
     */
    protected url(): string;
}
